Lower-level Details
===================

APIs for advanced use-cases.

.. nice-toc::

   color
      Working with colors.

   complete
      Building custom autocompleters.

   cli
      CLI parser internals.

   json_schema
      Building JSON schemas for configs.

   md
      Simple Markdown parser and renderer.

   string
      Colorized strings and formatting utilities.

   term
      Querying terminal capabilities.

   theme
      Controlling Yuio appearance.

   widget
      Interactive widgets.
